@@ -5,13 +5,15 @@ package App::Pinto::Admin::Command;
 use strict;
 use warnings;
 
+use Carp;
+
 #-----------------------------------------------------------------------------
 
 use App::Cmd::Setup -command;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.025_003'; # VERSION
+our $VERSION = '0.025_004'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -30,6 +32,31 @@ sub pinto {
     return $self->app->pinto();
 }
 
+#-----------------------------------------------------------------------------
+
+sub execute {
+    my ($self, $opts, $args) = @_;
+
+    $self->pinto->new_batch( %{$opts} );
+    $self->pinto->add_action( $self->action_name(), %{$opts} );
+    my $result = $self->pinto->run_actions();
+
+    return $result->is_success() ? 0 : 1;
+}
+
+#-----------------------------------------------------------------------------
+
+sub action_name {
+    my ($self) = @_;
+
+    my $class = ref $self || $self;
+
+    $class =~ m{ ([^:]+) $ }mx
+      or croak "Unable to parse Action name from $class";
+
+    return ucfirst $1;
+}
+
 #-----------------------------------------------------------------------------
 1;
 
@@ -45,7 +72,7 @@ App::Pinto::Admin::Command - Base class for pinto-admin commands
 
 =head1 VERSION
 
-version 0.025_003
+version 0.025_004
 
 =head1 AUTHOR
 
