@@ -14,7 +14,7 @@ use base 'App::Pinto::Admin::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.025_003'; # VERSION
+our $VERSION = '0.025_004'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -49,19 +49,6 @@ sub validate_args {
 
 #------------------------------------------------------------------------------
 
-sub execute {
-    my ($self, $opts, $args) = @_;
-
-    $self->pinto->new_batch( %{$opts} );
-    $self->pinto->add_action( 'List', %{$opts} );
-    my $result = $self->pinto->run_actions();
-
-    return $result->is_success() ? 0 : 1;
-
-}
-
-#------------------------------------------------------------------------------
-
 1;
 
 
@@ -76,7 +63,7 @@ App::Pinto::Admin::Command::list - list the contents of the repository
 
 =head1 VERSION
 
-version 0.025_003
+version 0.025_004
 
 =head1 SYNOPSIS
 
