@@ -13,7 +13,7 @@ use base 'App::Pinto::Admin::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.025_003'; # VERSION
+our $VERSION = '0.025_004'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -41,19 +41,6 @@ sub validate_args {
 }
 
 #------------------------------------------------------------------------------
-
-sub execute {
-    my ($self, $opts, $args) = @_;
-
-    $self->pinto->new_batch( %{$opts} );
-    $self->pinto->add_action('Nop', %{$opts} );
-    my $result = $self->pinto->run_actions();
-
-    return $result->is_success() ? 0 : 1;
-}
-
-#------------------------------------------------------------------------------
-
 1;
 
 
@@ -68,7 +55,7 @@ App::Pinto::Admin::Command::nop - initialize Pinto and exit
 
 =head1 VERSION
 
-version 0.025_003
+version 0.025_004
 
 =head1 SYNOPSIS
 
