@@ -11,7 +11,7 @@ use base 'App::Pinto::Admin::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.025_003'; # VERSION
+our $VERSION = '0.025_004'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -36,18 +36,6 @@ sub validate_args {
     return 1;
 }
 
-#------------------------------------------------------------------------------
-
-sub execute {
-    my ($self, $opts, $args) = @_;
-
-    $self->pinto->new_batch( %{$opts} );
-    $self->pinto->add_action('Purge');
-    my $result = $self->pinto->run_actions();
-
-    return $result->is_success() ? 0 : 1;
-}
-
 #------------------------------------------------------------------------------
 1;
 
@@ -63,7 +51,7 @@ App::Pinto::Admin::Command::purge - remove all distributions from the repository
 
 =head1 VERSION
 
-version 0.025_003
+version 0.025_004
 
 =head1 SYNOPSIS
 
