@@ -17,7 +17,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.025_003'; # VERSION
+our $VERSION = '0.025_004'; # VERSION
 
 #------------------------------------------------------------------------------
 # Moose attributes
@@ -65,6 +65,21 @@ sub BUILDARGS {
     return \%args;
 }
 
+#------------------------------------------------------------------------------
+
+sub BUILD {
+    my ($self) = @_;
+
+    unless (    -e $self->config->db_file()
+             && -e $self->config->modules_dir()
+             && -e $self->config->authors_dir() ) {
+
+      my $root_dir = $self->config->root_dir();
+      $self->fatal("Directory $root_dir does not look like a Pinto repository");
+    }
+
+    return $self;
+}
 
 #------------------------------------------------------------------------------
 # Builders
@@ -163,7 +178,7 @@ Pinto - Curate your own CPAN-like repository
 
 =head1 VERSION
 
-version 0.025_003
+version 0.025_004
 
 =head1 SYNOPSIS
 
@@ -177,7 +192,7 @@ See L<Pinto::Manual> for more information about the Pinto tools.
 
 =head1 DESCRIPTION
 
-L<Pinto> is a suite of tools for creating and managing a CPAN-like
+Pinto is a suite of tools for creating and managing a CPAN-like
 repository of Perl archives.  Pinto is inspired by L<CPAN::Mini>,
 L<CPAN::Mini::Inject>, and L<MyCPAN::App::DPAN>, but adds a few
 interesting features:
@@ -186,61 +201,98 @@ interesting features:
 
 =item * Pinto supports several usage patterns
 
-With L<Pinto>, you can create a repository to mirror the latest
+With Pinto, you can create a repository to mirror all the latest
 distributions from another repository.  Or you can create a "sparse
 repository" with just your own private distributions.  Or you can
 create a "project repository" that has all the distributions required
-for a particular project.  Or you can combine all of the above in some
+for a particular project.  Or you can combine any of the above in some
 way.
 
-=item * Pinto supports adding AND removing archives from the repository.
+=item * Pinto supports adding AND removing archives from the repository
 
-L<Pinto> gives you the power to precisely tune the contents of your
+Pinto gives you the power to precisely tune the contents of your
 repository.  So you can be sure that your downstream clients get
 exactly the stack of dependencies that you want them to have.
 
-=item * Pinto can be integrated with your version control system.
+=item * Pinto can be integrated with your version control system
 
-L<Pinto> can automatically commit to your version control system
-whenever the contents of the repository changes.  This gives you
-repeatable and identifiable snapshots of your dependencies, and a
-mechanism for rollback when things go wrong.
+Pinto can automatically commit to your version control system whenever
+the contents of the repository changes.  This gives you repeatable and
+identifiable snapshots of your dependencies, and a mechanism for
+rollback when things go wrong.
 
-=item * Pinto makes it easier to build several local repositories.
+=item * Pinto makes it easier to build several local repositories
 
-Creating new L<Pinto> repositories is easy, and each has its own
+Creating new Pinto repositories is easy, and each has its own
 configuration.  So you can have different repositories for each
 department, or each project, or each version of perl, or each
 customer, or whatever you want.
 
-=item * Pinto can pull archives from multiple remote repositories.
+=item * Pinto can pull archives from multiple remote repositories
 
-L<Pinto> can mirror or import distributions from multiple sources, so
-you can create private (or public) networks of repositories that
-enable separate teams or individuals to collaborate and share
-distributions.
+Pinto can mirror or import distributions from multiple sources, so you
+can create private (or public) networks of repositories that enable
+separate teams or individuals to collaborate and share distributions.
 
-=item * Pinto supports team development.
+=item * Pinto supports team development
 
-L<Pinto> is suitable for small to medium-sized development teams,
-where several developers might contribute new distributions at the
-same time.
+Pinto is suitable for small to medium-sized development teams, where
+several developers might contribute new distributions at the same
+time.  Pinto ensures that concurrent users don't step on each other.
 
 =item * Pinto has a robust command line interface.
 
 The L<pinto-admin> and L<pinto-remote> command line tools have options
-to control every aspect of your L<Pinto> repository.  They are well
+to control every aspect of your Pinto repository.  They are well
 documented and behave in a DWIM fashion.
 
 =item * Pinto can be extended.
 
-You can extend L<Pinto> by creating L<Pinto::Action> subclasses to
+You can extend Pinto by creating L<Pinto::Action> subclasses to
 perform new operations on your repository, such as extracting
 documentation from a distribution, or grepping the source code of
 several distributions.
 
 =back
 
+In some ways, Pinto is also similar to L<PAUSE|http://pause.perl.org>.
+Both are capable of accepting distributions and constructing a
+directory structure and index that toolchain clients understand.  But
+there are some important differences:
+
+=over
+
+=item * Pinto does not promise to index exactly like PAUSE does
+
+Over the years, PAUSE has evolved complicated heuristics for dealing
+with all the different ways that Perl code is written and
+distributions are organized.  Pinto is much less sophisticated, and
+only aspires to produce an index that is "good enough" for most
+applications.
+
+=item * Pinto does not understand author permissions
+
+PAUSE has a system of assigning ownership and co-maintenance
+permission to individuals or groups.  But Pinto only has a basic
+"first-come" system of ownership.  The ownerhsip controls are only
+advisory and can easily be bypassed (see next item below).
+
+=item * Pinto is not secure
+
+PAUSE requires authors to authenticate themselves before they can
+upload or remove distributions.  However, Pinto does not authenticate
+and permits users masquarade as anybody they want to be.  This is
+actually intentional and designed to encourage collaboration among
+developers.
+
+=back
+
+=head1 BUT WHERE IS THE API?
+
+For now, the Pinto API is private, undocumented, and subject to
+radical change without notice.  In the meantime, the command line
+utilties mentioned in the C</SYNOPSIS> are your public interface.
+
 =head1 SUPPORT
 
 =head2 Perldoc
