@@ -8,7 +8,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.025_003'; # VERSION
+our $VERSION = '0.025_004'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -23,7 +23,7 @@ override execute => sub {
 
     my $removed = 0;
     while ( my $dist = $dists->next() ) {
-        $self->repos->remove_distribution(path => $dist);
+        $self->repos->remove_distribution($dist);
         $removed++
     }
 
@@ -52,7 +52,7 @@ Pinto::Action::Purge - Remove all distributions from the repository
 
 =head1 VERSION
 
-version 0.025_003
+version 0.025_004
 
 =head1 AUTHOR
 
