@@ -12,7 +12,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.025_003'; # VERSION
+our $VERSION = '0.025_004'; # VERSION
 
 #------------------------------------------------------------------------------
 # ISA
@@ -48,7 +48,8 @@ override execute => sub {
     my $dist  = $self->repos->select_distributions( $where )->single();
     throw_error "Distribution $path does not exist" if not $dist;
 
-    $self->info(sprintf "Removing distribution $dist with %d packages", $dist->package_count());
+    my $count = $dist->package_count();
+    $self->info("Removing distribution $dist with $count packages");
 
     $self->repos->remove_distribution($dist);
 
@@ -77,7 +78,7 @@ Pinto::Action::Remove - Remove one distribution from the repository
 
 =head1 VERSION
 
-version 0.025_003
+version 0.025_004
 
 =head1 AUTHOR
 
