@@ -12,7 +12,7 @@ use namespace::autoclean;
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.025_003'; # VERSION
+our $VERSION = '0.025_004'; # VERSION
 
 #-------------------------------------------------------------------------------
 # ISA
@@ -39,7 +39,7 @@ override initialize => sub {
     my ($self) = @_;
 
     my $root_dir = $self->config->root_dir();
-    $self->info('Updating working copy');
+    $self->note('Updating working copy');
     Pinto::Util::Svn::svn_update(dir => $root_dir);
 
     return 1;
@@ -57,7 +57,7 @@ override add_file => sub {
         $path = $path->parent();
     }
 
-    $self->info("Scheduling $original_path for addition");
+    $self->debug("Scheduling $original_path for addition");
     Pinto::Util::Svn::svn_add(path => $path);
     $self->mark_path_as_added($path);
 
@@ -72,7 +72,7 @@ override remove_file => sub {
     my $file  = $args{file};
     return $self if not -e $file;
 
-    $self->info("Scheduling $file for removal");
+    $self->debug("Scheduling $file for removal");
     my $removed = Pinto::Util::Svn::svn_remove(path => $file);
     $self->mark_path_as_removed($removed);
 
@@ -136,7 +136,7 @@ Pinto::Store::VCS::Svn - Store your Pinto repository with Subversion
 
 =head1 VERSION
 
-version 0.025_003
+version 0.025_004
 
 =head1 SYNOPSIS
 
